@@ -9,6 +9,7 @@ from tenable.sc import TenableSC
 from tenable.io.exports import ExportsIterator
 from tenable.sc.analysis import AnalysisResultsIterator
 
+
 class Tio2Jira:
     _asset_cache = dict()
     _termed_assets = list()
@@ -26,7 +27,6 @@ class Tio2Jira:
         self._issue_types = self._jira.issue_types.upsert(config['issue_types'])
         self.screen_builder()
 
-
     def screen_builder(self):
         '''
         Builds the Field->Screen mapping as is necessary based off the
@@ -68,8 +68,8 @@ class Tio2Jira:
                     if tabname == 'default':
                         name = 'Field Tab'
 
-                    # look the the tab listing and set the tid to the id integer
-                    # if it exists.
+                    # look the the tab listing and set the tid to the id
+                    # integer if it exists.
                     for t in tabs:
                         if t['name'] == name:
                             tid = t['id']
@@ -174,9 +174,10 @@ class Tio2Jira:
                     'content': [{
                         'type': 'text',
                         'text': item['name']
-                }]})
+                    }]
+                })
 
-                # The paragraph is derrived from the appropriate
+                # The paragraph is derived from the appropriate
                 # field parameter.  If the string formatting fails
                 # from a KeyError, then replace the output with
                 # an empty paragraph.
@@ -195,10 +196,13 @@ class Tio2Jira:
                 except KeyError:
                     content.append({
                         'type': 'paragraph',
-                        'content': [{
-                            'type': 'text',
-                            'text': 'No Output'
-                    }]})
+                        'content': [
+                            {
+                                'type': 'text',
+                                'text': 'No Output'
+                            }
+                        ]
+                    })
             return {
                 'version': 1,
                 'type': 'doc',
@@ -208,7 +212,7 @@ class Tio2Jira:
         # if the definition is a dictionary, then this is a simple single-field
         # response and we should simple return back the processed string.
         elif isinstance(fdef, dict):
-            return fdef[fid].format(vuln=vuln)
+            return trunc(fdef[fid].format(vuln=vuln), limit=255)
 
     def _process_vuln(self, vuln, fid):
         '''
@@ -245,9 +249,13 @@ class Tio2Jira:
             # priority to the severity rating.
             sevprio = self.config['tenable'].get('severity_prioritization')
             if f['jira_field'] == 'Vulnerability Severity' and sevprio:
-                p = {'id': str(sevprio[value.lower()])}
-                issue['priority'] = p
-                subissue['priority'] = p
+                if value.lower() in sevprio:
+                    p = {'id': str(sevprio[value.lower()])}
+                    issue['priority'] = p
+                    subissue['priority'] = p
+                else:
+                    self._log.debug('Severity {} not found in {}'.format(value, sevprio))
+
             processed = None
 
             if value:
@@ -522,13 +530,16 @@ class Tio2Jira:
             v = flatten(vulnitem)
             self._process_closed_vuln(v, fid)
 
-    def ingest(self, observed_since):
+    def ingest(self, observed_since, first_discovery):
         '''
         Perform the vuln ingestion and transformation.
 
         Args:
             observed_since (int):
                 Unix Timestamp detailing the threshold for vuln age.
+            first_discovery (bool):
+                Whether to add all observed vulns or only those identified
+                for the first time within the age threshold.
         '''
         observed_since = int(observed_since)
         tags = list()
@@ -613,14 +624,28 @@ class Tio2Jira:
             vpr = None
             if self.config['tenable'].get('tio_vpr_thresh'):
                 vpr = {'gte': self.config['tenable'].get('tio_vpr_thresh')}
-            vulns = self._src.exports.vulns(
-                include_unlicensed=True,
-                last_found=observed_since,
-                severity=self.config['tenable']['tio_severities'],
-                num_assets=self.config['tenable'].get('chunk_size', 1000),
-                vpr=vpr,
-                tags=tags
-            )
+
+            # When only looking for new vulnerabilities, use first_found rather
+            # than last_found as the filter to tenable's API to limit results.
+            if first_discovery:
+                vulns = self._src.exports.vulns(
+                    include_unlicensed=True,
+                    first_found=observed_since,
+                    severity=self.config['tenable']['tio_severities'],
+                    num_assets=self.config['tenable'].get('chunk_size', 1000),
+                    vpr=vpr,
+                    tags=tags
+                )
+            else:
+                vulns = self._src.exports.vulns(
+                    include_unlicensed=True,
+                    last_found=observed_since,
+                    severity=self.config['tenable']['tio_severities'],
+                    num_assets=self.config['tenable'].get('chunk_size', 1000),
+                    vpr=vpr,
+                    tags=tags
+                )
+
             self._log.info('Updating and creating issues marked as Open')
             self.create_issues(vulns)
 
@@ -632,7 +657,9 @@ class Tio2Jira:
                 last_fixed=observed_since,
                 state=['fixed'],
                 severity=self.config['tenable']['tio_severities'],
-                num_assets=self.config['tenable'].get('chunk_size', 1000))
+                num_assets=self.config['tenable'].get('chunk_size', 1000),
+                tags=tags
+            )
             self._log.info('Closing Issues Marked as Fixed.')
             self.close_issues(closed)
 
@@ -681,9 +708,11 @@ class Tio2Jira:
         # appropriate analysis calls using the query id specified.
         if isinstance(self._src, TenableSC):
             # using the query specified, overload the tool and the last_seen
-            # filter to pull data from the appropriate timeframe.
+            # or first_seen filter to pull data from the appropriate timeframe.
+            seen_filter = 'lastSeen' if not first_discovery else 'firstSeen'
+
             vulns = self._src.analysis.vulns(
-                ('lastSeen', '=', '{}-{}'.format(
+                (seen_filter, '=', '{}-{}'.format(
                     observed_since, int(time.time()))),
                 query_id=self.config['tenable'].get('query_id'),
                 limit=self.config['tenable'].get('page_size', 1000),
